/**
 * CFilter - 页面筛选
 * @author Tevin
 */

<template>
    <view class="c-filter">
        <view
            class="c-filter-bar"
            v-if="bar"
        >
            <CFilterSelect
                v-if="bar.type==='select'"
                type="bar"
                :label="bar.label"
                :options="selectOptions[bar.name]"
                :value="filterRes[bar.name]"
                :onChange="evt=>handleBarChange(bar.name, evt)"
            />
            <CFilterDateRange
                v-if="bar.type==='dateRange'"
                type="bar"
                :label="bar.label"
                :value="filterRes[bar.name]"
                :onChange="evt=>handleItemChange(bar.name, evt)"
            />
        </view>
        <view
            class="c-filter-more"
            :class="itemsFilled?'on':''"
            v-if="items && items.length > 0"
            @tap="evt => handleOpen()"
        >
            <text>更多筛选 </text>
            <text class="arrow">»</text>
        </view>
        <AtDrawer
            class="c-filter-drawer"
            mask
            right
            :show="drawerShow"
            :onClose="evt => handleFinish()"
        >
            <scroll-view
                class="c-filter-drawer-list"
                :scrollY="true"
                v-if="drawerDisplay"
            >
                <view
                    class="box"
                    v-for="(item,index) in items"
                    :key="index"
                >
                    <CFilterSelect
                        v-if="item.type==='select'"
                        type="item"
                        :label="item.label"
                        :options="selectOptions[item.name]"
                        :value="filterRes[item.name]"
                        :onChange="evt=>handleItemChange(item.name, evt)"
                    />
                    <CFilterDateRange
                        v-if="item.type==='dateRange'"
                        type="item"
                        :label="item.label"
                        :value="filterRes[item.name]"
                        :onChange="evt=>handleItemChange(item.name, evt)"
                    />
                </view>
            </scroll-view>
            <view class="c-filter-drawer-btn">
                <AtButton
                    type="primary"
                    :circle="false"
                    :onClick="evt => handleClean()"
                >重置</AtButton>
                <AtButton
                    type="primary"
                    :circle="false"
                    :onClick="evt => handleFinish()"
                >完成</AtButton>
            </view>
        </AtDrawer>
    </view>
</template>

<script>
import Taro from '@tarojs/taro';
import { AtDrawer, AtButton } from 'taro-ui-vue';
import CFilterSelect from './CFilterSelect';
import CFilterDateRange from './CFilterDateRange';
import './cFilter.scss';

export default {
    name: 'CFilter',
    components: {
        AtDrawer,
        AtButton,
        CFilterSelect,
        CFilterDateRange,
    },
    props: {
        // 筛选横条项目
        bar: { type: Object, default: {} },
        // 筛选展开层项目列表
        items: { type: Array, default: [] },
        // 各个项目的选项列表
        selectOptions: { type: Object, default: {} },
        // 筛选变化时的回调
        onChange: Function,
    },
    data() {
        return {
            filterRes: {},
            drawerShow: false,
            drawerDisplay: false,
            // 面板项有已选
            itemsFilled: false,
            // 本次打开是否有改变
            itemsChanged: false,
        };
    },
    methods: {
        handleOpen() {
            this.drawerShow = true;
            this.$nextTick(() => {
                setTimeout(() => {
                    this.drawerDisplay = true;
                }, 80);
            });
        },
        handleBarChange(name, value) {
            this.$set(this.filterRes, name, value);
            this.onChange(this.filterRes);
        },
        handleItemChange(name, value) {
            this.$set(this.filterRes, name, value);
            this.itemsChanged = true;
            // 如果变化值不为空
            if (typeof value !== 'undefined') {
                this.itemsFilled = true;
            }
            // 为空是检查所有面板值是否为空
            else {
                let valuehas = false;
                for (let item of this.items) {
                    if (typeof this.filterRes[item.name] !== 'undefined') {
                        valuehas = true;
                        break;
                    }
                }
                this.itemsFilled = valuehas;
            }
        },
        handleClean() {
            Object.keys(this.filterRes).forEach(key => {
                this.filterRes[key] = [][0];
            });
            this.itemsFilled = false;
            this.itemsChanged = false;
            this.onChange(this.filterRes);
        },
        handleFinish() {
            this.drawerShow = false;
            this.$nextTick(() => {
                this.drawerDisplay = false;
            });
            // 有项目改变时，发送变化
            if (this.itemsChanged) {
                this.itemsChanged = false;
                this.onChange(this.filterRes);
            }
        },
    },
};
</script>
